==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1alpha1InitializerFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1alpha1InitializerFluent<A extends V1alpha1InitializerFluent<A>> extends Fluent<A>{


    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A addToRules(int index,V1alpha1Rule item);
    public A setToRules(int index,V1alpha1Rule item);
    public A addToRules(V1alpha1Rule... items);
    public A addAllToRules(Collection<V1alpha1Rule> items);
    public A removeFromRules(V1alpha1Rule... items);
    public A removeAllFromRules(Collection<V1alpha1Rule> items);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1Rule> getRules();
    public List<V1alpha1Rule> buildRules();
    public V1alpha1Rule buildRule(int index);
    public V1alpha1Rule buildFirstRule();
    public V1alpha1Rule buildLastRule();
    public V1alpha1Rule buildMatchingRule(io.kubernetes.client.fluent.Predicate<V1alpha1RuleBuilder> predicate);
    public A withRules(List<V1alpha1Rule> rules);
    public A withRules(V1alpha1Rule... rules);
    public Boolean hasRules();
    public V1alpha1InitializerFluent.RulesNested<A> addNewRule();
    public V1alpha1InitializerFluent.RulesNested<A> addNewRuleLike(V1alpha1Rule item);
    public V1alpha1InitializerFluent.RulesNested<A> setNewRuleLike(int index,V1alpha1Rule item);
    public V1alpha1InitializerFluent.RulesNested<A> editRule(int index);
    public V1alpha1InitializerFluent.RulesNested<A> editFirstRule();
    public V1alpha1InitializerFluent.RulesNested<A> editLastRule();
    public V1alpha1InitializerFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<V1alpha1RuleBuilder> predicate);

    public interface RulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1RuleFluent<V1alpha1InitializerFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1alpha1InitializerFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1alpha1InitializerFluent<A extends V1alpha1InitializerFluent<A>> extends Fluent<A>{


    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public A addToRules(int index,V1alpha1Rule item);
    public A setToRules(int index,V1alpha1Rule item);
    public A addToRules(V1alpha1Rule... items);
    public A addAllToRules(Collection<V1alpha1Rule> items);
    public A removeFromRules(V1alpha1Rule... items);
    public A removeAllFromRules(Collection<V1alpha1Rule> items);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1Rule> getRules();
    public List<V1alpha1Rule> buildRules();
    public V1alpha1Rule buildRule(int index);
    public V1alpha1Rule buildFirstRule();
    public V1alpha1Rule buildLastRule();
    public V1alpha1Rule buildMatchingRule(io.kubernetes.client.fluent.Predicate<V1alpha1RuleBuilder> predicate);
    public Boolean hasMatchingRule(io.kubernetes.client.fluent.Predicate<V1alpha1RuleBuilder> predicate);
    public A withRules(List<V1alpha1Rule> rules);
    public A withRules(V1alpha1Rule... rules);
    public Boolean hasRules();
    public V1alpha1InitializerFluent.RulesNested<A> addNewRule();
    public V1alpha1InitializerFluent.RulesNested<A> addNewRuleLike(V1alpha1Rule item);
    public V1alpha1InitializerFluent.RulesNested<A> setNewRuleLike(int index,V1alpha1Rule item);
    public V1alpha1InitializerFluent.RulesNested<A> editRule(int index);
    public V1alpha1InitializerFluent.RulesNested<A> editFirstRule();
    public V1alpha1InitializerFluent.RulesNested<A> editLastRule();
    public V1alpha1InitializerFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<V1alpha1RuleBuilder> predicate);

    public interface RulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1RuleFluent<V1alpha1InitializerFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}


}
